@@ -6,7 +6,7 @@ use 5.008004;
 use Alien::Build::Plugin;
 
 # ABSTRACT: Core Alien::Build plugin to maintain compatibility with legacy Alien::Base
-our $VERSION = '2.47'; # VERSION
+our $VERSION = '2.83'; # VERSION
 
 
 sub init
@@ -53,7 +53,7 @@ Alien::Build::Plugin::Core::Legacy - Core Alien::Build plugin to maintain compat
 
 =head1 VERSION
 
-version 2.47
+version 2.83
 
 =head1 SYNOPSIS
 
@@ -62,7 +62,7 @@ version 2.47
 
 =head1 DESCRIPTION
 
-This plugin provides some compatibility with the legacy L<Alien::Build::ModuleBuild>
+This plugin provides some compatibility with the legacy L<Alien::Base::ModuleBuild>
 interfaces.
 
 =head1 SEE ALSO
@@ -131,9 +131,11 @@ Håkon Hægland (hakonhagland, HAKONH)
 
 nick nauwelaerts (INPHOBIA)
 
+Florian Weimer
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2011-2022 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
